@@ -28,9 +28,23 @@ class Loader:
             self.progress += 1
 
     def progress_bar(self, bar_length=30):
-        percent = int((self.progress / bar_length) * 100)
+        percent = int((self.progress / bar_length * 2) * 100)
         filled = int(self.progress / bar_length * bar_length)
         empty = bar_length - filled
         filled_bar = Fore.RED + '-' * filled + Style.RESET_ALL
         empty_bar = Fore.LIGHTBLACK_EX + '-' * empty + Style.RESET_ALL
         return f"{filled_bar}{empty_bar}"
+    
+class Process:
+    def __init__(self, func):
+        self.func = func
+
+    def __call__(self, *args, **kwargs):
+        loader = Loader("Loading...")
+        loader.start()
+        result = self.func(*args, **kwargs)
+        loader.stop()
+        return result
+
+def process(func):
+    return Process(func)
